@@ -3,33 +3,33 @@
 #' @keywords internal
 #' @note see `crminer::crm_text`
 #' @rdname cr_ft_text-defunct
-cr_ft_text <- function(...) {
+cr_ft_text <- function(...) { # nocov start
   .Defunct(package = "crminer", msg = "Removed - see crminer::crm_text()")
-}
+} # nocov end
 
 #' Get full text plain from a DOI
 #' @export
 #' @keywords internal
 #' @note see `crminer::crm_plain`
 #' @rdname cr_ft_plain-defunct
-cr_ft_plain <- function(...) {
+cr_ft_plain <- function(...) { # nocov start
   .Defunct(package = "crminer", msg = "Removed - see crminer::crm_plain()")
-}
+} # nocov end
 
 #' Get full text xml from a DOI
 #' @export
 #' @keywords internal
 #' @note see `crminer::crm_xml`
 #' @rdname cr_ft_xml-defunct
-cr_ft_xml <- function(...) {
+cr_ft_xml <- function(...) { # nocov start
   .Defunct(package = "crminer", msg = "Removed - see crminer::crm_xml()")
-}
+} # nocov end
 
 #' Get full text pdf from a DOI
 #' @export
 #' @keywords internal
 #' @note see `crminer::crm_pdf`
 #' @rdname cr_ft_pdf-defunct
-cr_ft_pdf <- function(...) {
+cr_ft_pdf <- function(...) { # nocov start
   .Defunct(package = "crminer", msg = "Removed - see crminer::crm_pdf()")
-}
+} # nocov end
