@@ -3,13 +3,13 @@
 #' @export
 #' @rdname pmid2doi-defunct
 #' @keywords internal
-`pmid2doi` <- function(...){
+`pmid2doi` <- function(...){ # nocov start
   .Defunct(msg = "The web API behind this function is down indefinitely, 
            see id_converter()")
-}
+} # nocov end
 
 #' @export
 #' @rdname pmid2doi-defunct
-`doi2pmid` <- function(...){
+`doi2pmid` <- function(...){ # nocov start
   .Defunct(msg = "The web API behind this function is down indefinitely, see id_converter()")
-}
+} # nocov end
